@@ -29,14 +29,10 @@ import signal
 import stat
 import time
 import glob
-import fcntl
 
-# Only on Unix
-try:
-    import pwd
-    import grp
-except ImportError:
-    pass
+import fcntl
+import pwd
+import grp
 
 from exceptions import *
 
@@ -52,6 +48,16 @@ _bool_values = {
     '0'     : False
 }
 
+#######################################
+def lock_file(file):
+    '''Do fcntl file locking.'''
+    fcntl.flock(file.fileno(), fcntl.LOCK_EX)
+
+#######################################
+def unlock_file(file):
+    '''Do fcntl file unlocking.'''
+    fcntl.flock(file.fileno(), fcntl.LOCK_UN)
+
 #######################################
 def safe_open(path, mode):
     '''Open a file path safely.
@@ -94,9 +100,9 @@ class updatefile(object):
             if hasattr(self, 'file'):
                 self.file.close()
         except IOError:
-            pass            
+            pass
         self.closed = True
-        
+
     def close(self):
         if self.closed or not hasattr(self, 'file'):
             return
@@ -265,7 +271,7 @@ def deliver_maildir(maildirpath, data, hostname, dcount=None):
 
     except IOError, o:
         signal.alarm(0)
-        raise getmailDeliveryError('failure writing file %s (%s)' 
+        raise getmailDeliveryError('failure writing file %s (%s)'
             % (fname_tmp, o))
 
     # Move message file from Maildir/tmp to Maildir/new
@@ -297,16 +303,6 @@ def mbox_from_escape(s):
     '''Escape spaces, tabs, and newlines in the envelope sender address.'''
     return ''.join([(c in (' ', '\t', '\n')) and '-' or c for c in s])
 
-#######################################
-def lock_file(file):
-    '''Do fcntl file locking.'''
-    fcntl.flock(file.fileno(), fcntl.LOCK_EX)
-
-#######################################
-def unlock_file(file):
-    '''Do fcntl file unlocking.'''
-    fcntl.flock(file.fileno(), fcntl.LOCK_UN)
-
 #######################################
 def address_no_brackets(addr):
     '''Strip surrounding <> on an email address, if present.'''
